@@ -2,5 +2,8 @@
 # SPDX - License - Identifier: MIT
 
 from showinfm.showinfm import (
-    show_in_file_manager, valid_file_manager, user_file_manager, stock_file_manager
+    show_in_file_manager,
+    valid_file_manager,
+    user_file_manager,
+    stock_file_manager,
 )
